@@ -368,7 +368,7 @@ namespace Aws
                 int GetInitializationError() const noexcept { return m_initializationError; }
 
                 /// @private
-                aws_tls_ctx *GetUnderlyingHandle() noexcept { return m_ctx.get(); }
+                aws_tls_ctx *GetUnderlyingHandle() const noexcept { return m_ctx.get(); }
 
               private:
                 bool isValid() const noexcept { return m_ctx && m_initializationError == AWS_ERROR_SUCCESS; }
